from colorfulpanda.Style.Base import BaseStyle

style0 = BaseStyle(False, False, [52])
style1 = BaseStyle(False, False, [196,124,88,52])
style2 = BaseStyle(False, False, [196, 88])
style3 = BaseStyle(False, False, [196])
style4 = BaseStyle(True, True, [196])